@@ -1,4 +1,4 @@
-# Copyright (C) 2012 by Dr. Dieter Maurer <dieter@handshake.de>; see 'LICENSE.txt' for details
+# Copyright (C) 2012-2018 by Dr. Dieter Maurer <dieter@handshake.de>; see 'LICENSE.txt' for details
 """Auxiliary classes to construct signature/encryption templates."""
 
 from lxml.etree import ElementBase, \
@@ -74,7 +74,7 @@ def Signature(c14nMethod, signMethod, id=None, nsPrefix=None):
              )
   mkse(info, dsig("SignatureMethod"), Algorithm=signMethod.href)
   attrib = id and dict(Id=id) or None
-  nsmap = nsPrefix and dict(nsPrefix=DSigNs) or DSigNsMap
+  nsmap = nsPrefix and {nsPrefix:DSigNs} or DSigNsMap
   return _Signature(info, mke(dsig("SignatureValue")), attrib=attrib, nsmap=nsmap)
 
 
@@ -90,9 +90,9 @@ class _Reference(_DSigBase):
 
 def Reference(digestMethod, id=None, uri=None, type=None):
     attrib = {}
-    if id: attrib["Id"] = id
-    if uri: attrib["URI"] = uri
-    if type: attrib["Type"] = type
+    if id is not None: attrib["Id"] = id
+    if uri is not None: attrib["URI"] = uri
+    if type is not None: attrib["Type"] = type
     return mke(
       dsig("Reference"),
       mke(dsig("DigestMethod"), Algorithm=digestMethod.href),
@@ -311,7 +311,7 @@ class _EncKey(_EncType):
   def addDataReference(self, uri=None):
     rl = self.find(enc("ReferenceList"))
     if rl is None:
-      rl = mke(self, enc("ReferenceList"))
+      rl = mke(enc("ReferenceList"))
       self.insert(0, rl)
     return mkse(rl, enc("DataReference"),
                       attrib=uri and dict(URI=uri) or None
@@ -320,7 +320,7 @@ class _EncKey(_EncType):
   def addKeyReference(self, uri=None):
     rl = self.find(enc("ReferenceList"))
     if rl is None:
-      rl = mke(self, enc("ReferenceList"))
+      rl = mke(enc("ReferenceList"))
       self.insert(0, rl)
     return mkse(rl, enc("KeyReference"),
                       attrib=uri and dict(URI=uri) or None
@@ -334,7 +334,7 @@ def _EncType_(tag, encMethod=None, id=None, type=None, mimeType=None, encoding=N
   if mimeType: attrib["MimeType"] = mimeTpye
   if encoding: attrib["Encoding"] = encoding
   if recipient: attrib["Recipient"] = recipient
-  nsmap = nsPrefix and dict(nsPrefix=EncNs) or EncNsMap
+  nsmap = nsPrefix and {nsPrefix:EncNs} or EncNsMap
   et = mke(enc(tag), attrib=attrib, nsmap=nsmap)
   if encMethod:
     mkse(et, enc("EncryptionMethod"), Algorithm=encMethod.href)
